@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: 100.panel.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: 100.panel.php 657 2010-03-21 20:21:29Z d00p $
  */
 
 return array(
@@ -77,6 +77,24 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingField',
 					),
+				'panel_adminmail_defname' => array(
+					'label' => $lng['serversettings']['adminmail_defname'],
+					'settinggroup' => 'panel',
+					'varname' => 'adminmail_defname',
+					'type' => 'string',
+					'default' => 'Froxlor Administrator',
+					'save_method' => 'storeSettingField',
+					),
+				'panel_adminmail_return' => array(
+					'label' => $lng['serversettings']['adminmail_return'],
+					'settinggroup' => 'panel',
+					'varname' => 'adminmail_return',
+					'type' => 'string',
+					'string_type' => 'mail',
+					'string_emptyallowed' => true,
+					'default' => '',
+					'save_method' => 'storeSettingField',
+					),
 				'panel_decimal_places' => array(
 					'label' => $lng['serversettings']['decimal_places'],
 					'settinggroup' => 'panel',
