@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 110.accounts.php 1189 2010-07-19 08:06:18Z d00p $
+ * @version    $Id: 110.accounts.php 1342 2010-10-15 11:48:05Z d00p $
  */
 
 return array(
@@ -38,6 +38,14 @@ return array(
 					'default' => false,
 					'save_method' => 'storeSettingField',
 					),
+				'login_domain_login' => array(
+					'label' => $lng['serversettings']['login_domain_login'],
+					'settinggroup' => 'login',
+					'varname' => 'domain_login',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField',
+					),
 				'login_maxloginattempts' => array(
 					'label' => $lng['serversettings']['maxloginattempts'],
 					'settinggroup' => 'login',
