@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 120.system.php 1345 2010-10-16 20:00:24Z d00p $
+ * @version    $Id: 120.system.php 1492 2010-11-27 10:37:44Z Dessa $
  */
 
 return array(
@@ -28,7 +28,6 @@ return array(
 					'varname' => 'documentroot_prefix',
 					'type' => 'string',
 					'default' => '/var/customers/webs/',
-					'plausibility_check_method' => 'checkPathConflicts',
 					'save_method' => 'storeSettingField',
 					),
 				'system_ipaddress' => array(
@@ -59,22 +58,6 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingHostname',
 					),
-				'system_froxlordirectlyviahostname' => array(
-					'label' => $lng['serversettings']['froxlordirectlyviahostname'],
-					'settinggroup' => 'system',
-					'varname' => 'froxlordirectlyviahostname',
-					'type' => 'bool',
-					'default' => false,
-					'save_method' => 'storeSettingField',
-					),
-				'system_stdsubdomain' => array(
-					'label' => $lng['serversettings']['stdsubdomainhost'],
-					'settinggroup' => 'system',
-					'varname' => 'stdsubdomain',
-					'type' => 'string',
-					'default' => '',
-					'save_method' => 'storeSettingHostname',
-					),
 				'system_mysql_access_host' => array(
 					'label' => $lng['serversettings']['mysql_access_host'],
 					'settinggroup' => 'system',
@@ -101,6 +84,18 @@ return array(
 					'default' => true,
 					'save_method' => 'storeSettingField',
 					),
+				'system_httpuser' => array(
+					'settinggroup' => 'system',
+					'varname' => 'httpuser',
+					'type' => 'hidden',
+					'default' => 'www-data',
+					),
+				'system_httpgroup' => array(
+					'settinggroup' => 'system',
+					'varname' => 'httpgroup',
+					'type' => 'hidden',
+					'default' => 'www-data',
+					),
 				'system_debug_cron' => array(
 					'label' => $lng['serversettings']['cron']['debug'],
 					'settinggroup' => 'system',
