@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_mysql.php 1245 2010-08-10 09:21:07Z d00p $
+ * @version    $Id: customer_mysql.php 1504 2010-11-29 06:40:35Z d00p $
  */
 
 define('AREA', 'customer');
@@ -126,7 +126,11 @@ elseif($page == 'mysqls')
 			}
 			else
 			{
-				ask_yesno('mysql_reallydelete', $filename, array('id' => $id, 'page' => $page, 'action' => $action), $result['databasename']);
+				$dbnamedesc = $result['databasename'];
+				if($result['description'] != '') {
+					$dbnamedesc.= ' ('.$result['description'].')';
+				}
+				ask_yesno('mysql_reallydelete', $filename, array('id' => $id, 'page' => $page, 'action' => $action), $dbnamedesc);
 			}
 		}
 	}
