@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: install.php 1387 2010-10-23 10:20:23Z EleRas $
+ * @version    $Id: install.php 1484 2010-11-26 12:30:54Z Dessa $
  */
 
 /**
@@ -22,6 +22,12 @@
  * installer, (c) 1999 - 2004 phpBB Group.
  */
 
+// ensure that default timezone is set
+if(function_exists("date_default_timezone_set") && function_exists("date_default_timezone_get"))
+{
+	@date_default_timezone_set(@date_default_timezone_get());
+}
+
 if(file_exists('../lib/userdata.inc.php'))
 {
 	/**
@@ -443,6 +449,11 @@ else
 	{
 		$webserver = 'lighttpd';
 	}
+    elseif(substr(strtoupper(@php_sapi_name()), 0, 8) == "NGINX"
+	       || stristr($_SERVER['SERVER_SOFTWARE'], "nginx"))
+	{
+		$webserver = 'nginx';
+	}
 	else
 	{
 		// we don't need to bail out, since unknown does not affect any critical installation routines
@@ -665,6 +676,14 @@ if(isset($_POST['installstep'])
 		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/lighttpd/lighttpd.pem' WHERE `settinggroup` = 'system' AND `varname` = 'ssl_cert_file'");
 		$ssettings = '';
 	}
+        elseif($webserver == "nginx")
+	{
+		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/nginx/sites-enabled/' WHERE `settinggroup` = 'system' AND `varname` = 'apacheconf_vhost'");
+		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/nginx/sites-enabled/' WHERE `settinggroup` = 'system' AND `varname` = 'apacheconf_diroptions'");
+		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/nginx/froxlor-htpasswd/' WHERE `settinggroup` = 'system' AND `varname` = 'apacheconf_htpasswddir'");
+		$db->query("UPDATE `" . TABLE_PANEL_SETTINGS . "` SET `value` = '/etc/init.d/nginx reload' WHERE `settinggroup` = 'system' AND `varname` = 'apachereload_command'");
+		$ssettings = '';
+	}
 
 	// insert the lastcronrun to be the installation date
 
@@ -895,7 +914,7 @@ else
 			</tr>
 			<tr>
 				<td class="main_field_name"<?php echo ((!empty($_POST['installstep']) && $webserver == '') ? ' style="color:red;"' : ''); ?>><?php echo $lng['install']['webserver']; ?>:</td>
-				<td class="main_field_display"><input type="radio" name="webserver" value="apache2" <?php echo $webserver == "apache2" ? 'checked="checked"' : "" ?>/>Apache2&nbsp;<br /><input type="radio" name="webserver" value="lighttpd" <?php echo $webserver == "lighttpd" ? 'checked="checked"' : "" ?>/>Lighttpd</td>
+				<td class="main_field_display"><input type="radio" name="webserver" value="apache2" <?php echo $webserver == "apache2" ? 'checked="checked"' : "" ?>/>Apache2&nbsp;<br /><input type="radio" name="webserver" value="lighttpd" <?php echo $webserver == "lighttpd" ? 'checked="checked"' : "" ?>/>Lighttpd2&nbsp;<br /><input type="radio" name="webserver" value="nginx" <?php echo $webserver == "nginx" ? 'checked="checked"' : "" ?>/>Nginx</td>
 			</tr>
 			<tr>
 				<td class="main_field_name"<?php echo ((!empty($_POST['installstep']) && $serverip == '') ? ' style="color:red;"' : ''); ?>><?php echo $lng['install']['httpuser']; ?>:</td>
