@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Logger
- * @version    $Id: class.FileLogger.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: class.FileLogger.php 937 2010-05-17 06:09:30Z d00p $
  * @link       http://www.nutime.de/
  * 
  * Logger - File-Logger-Class
@@ -169,7 +169,7 @@ class FileLogger extends AbstractLogger
 		}
 	}
 
-	private function setLogFile($filename = null)
+	public function setLogFile($filename = null)
 	{
 		if($filename != null
 		   && $filename != ''
