@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Logger
- * @version    $Id: class.ticket.php 1329 2010-10-10 08:20:32Z d00p $
+ * @version    $Id: class.ticket.php 1447 2010-11-08 07:11:00Z d00p $
  * @link       http://www.nutime.de/
  *
  * Support Tickets - Tickets-Class
@@ -320,7 +320,7 @@ class ticket
 			if ($_mailerror) {
 				$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'ticket_class'), $this->db, $this->settings);
 				$rstlog->logAction(ADM_ACTION, LOG_ERR, "Error sending mail: " . $mailerr_msg);
-				standard_error(array('errorsendingmail', $usr['email']));
+				standard_error('errorsendingmail', $usr['email']);
 			}
 
 			$mail->ClearAddresses();
@@ -348,7 +348,7 @@ class ticket
 			if ($_mailerror) {
 				$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'ticket_class'), $this->db, $this->settings);
 				$rstlog->logAction(ADM_ACTION, LOG_ERR, "Error sending mail: " . $mailerr_msg);
-				standard_error(array('errorsendingmail', $admin['email']));
+				standard_error('errorsendingmail', $admin['email']);
 			}
 
 			$mail->ClearAddresses();
@@ -442,6 +442,20 @@ class ticket
 		return null;
 	}
 
+	/**
+	 * get the highest order number
+	 * 
+	 * @param object $_db database-object
+	 * 
+	 * @return int highest order number
+	 */
+	static public function getHighestOrderNumber($_db = null)
+	{
+		$sql = "SELECT MAX(`logicalorder`) as `highestorder` FROM `" . TABLE_PANEL_TICKET_CATS . "`;";
+		$result = $_db->query_first($sql);
+		return (isset($result['highestorder']) ? (int)$result['highestorder'] : 1);
+	}
+
 	/**
 	 * returns the last x archived tickets
 	 */
