@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: freebsd.inc.php 1277 2010-09-13 06:11:25Z d00p $
+ * @version    $Id: freebsd.inc.php 1453 2010-11-16 06:22:02Z d00p $
  */
 
 return Array(
@@ -88,8 +88,8 @@ return Array(
 							'make install'
 						),
 						'commands_2' => Array(
-							'pw groupadd vmail -g 5001 ',
-							'pw useradd vmail -u 5001 -g 5001 -s/sbin/nologin -d/dev/null',			
+							'pw groupadd vmail -g '.$settings['system']['vmail_gid'],
+							'pw useradd vmail -u '.$settings['system']['vmail_uid'].' -g '.$settings['system']['vmail_gid'].' -s/sbin/nologin -d/dev/null',			
 							'mkdir -p ' . $settings['system']['vmail_homedir'],
 							'chown -R vmail:vmail ' . $settings['system']['vmail_homedir'],
 							'chmod 0750 ' . $settings['system']['vmail_homedir']
