@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: gentoo.inc.php 1396 2010-10-24 08:59:00Z d00p $
+ * @version    $Id: gentoo.inc.php 1485 2010-11-26 12:32:47Z Dessa $
  */
 
 return Array(
@@ -62,7 +62,49 @@ return Array(
 							'rc-update add lighttpd default',
 							'/etc/init.d/lighttpd restart'
 						)
-					)
+					),
+					'nginx' => Array(
+						'label' => 'Nginx Webserver',
+						'commands_1' => Array(
+							'emerge nginx',
+						),
+						'files' => Array(
+							'etc_nginx_nginx.conf' => '/etc/nginx/nginx.conf',
+							'etc_init.d_php-fcgi' => '/etc/init.d/php-fcgi'
+						),
+						'commands_2' => Array(
+							'mkdir -p ' . $settings['system']['documentroot_prefix'],
+							'mkdir -p ' . $settings['system']['logfiles_directory'],
+							'mkdir -p ' . $settings['system']['deactivateddocroot'],
+							'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
+							'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir'],
+							'chmod u+x /etc/init.d/php-fcgi'
+						),
+						'restart' => Array(
+							'/etc/init.d/nginx restart'
+						)
+					),
+                                        'nginx' => Array(
+                                                'label' => 'Nginx Webserver',
+                                                'commands_1' => Array(
+                                                        'emerge nginx',
+                                                ),
+                                                'files' => Array(
+                                                        'etc_nginx_nginx.conf' => '/etc/nginx/nginx.conf',
+                                                        'etc_init.d_php-fcgi' => '/etc/init.d/php-fcgi'
+                                                ),
+                                                'commands_2' => Array(
+                                                        'mkdir -p ' . $settings['system']['documentroot_prefix'],
+                                                        'mkdir -p ' . $settings['system']['logfiles_directory'],
+                                                        'mkdir -p ' . $settings['system']['deactivateddocroot'],
+                                                        'mkdir -p ' . $settings['system']['mod_fcgid_tmpdir'],
+                                                        'chmod 1777 ' . $settings['system']['mod_fcgid_tmpdir'],
+                                                        'chmod u+x /etc/init.d/php-fcgi'
+                                                ),
+                                                'restart' => Array(
+                                                        '/etc/init.d/nginx restart'
+                                                )
+                                        )
 				)
 			),
 			'dns' => Array(
