@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.makeCorrectFile.php 138 2010-01-27 08:54:31Z Dessa $
+ * @version    $Id: function.makeCorrectFile.php 1174 2010-06-28 08:23:11Z d00p $
  */
 
 /**
@@ -29,6 +29,15 @@
 
 function makeCorrectFile($filename)
 {
+	if (!isset($filename)
+		|| trim($filename) == ''
+	) {
+		$error = 'Given filename for function '.__FUNCTION__.' is empty.'."\n";
+		$error.= 'This is very dangerous and should not happen.'."\n";
+		$error.= 'Please inform the Froxlor team about this issue so they can fix it.';
+		die($error);
+	}
+
 	if(substr($filename, 0, 1) != '/')
 	{
 		$filename = '/' . $filename;
