@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.makePathfield.php 929 2010-05-11 11:16:14Z d00p $
+ * @version    $Id: function.makePathfield.php 1257 2010-08-20 14:45:37Z d00p $
  */
 
 /**
@@ -76,7 +76,7 @@ function makePathfield($path, $uid, $gid, $fieldType, $value = '')
 				// for the Dropdown, #225
 				$value = substr($value, 1);
 				$field = $lng['panel']['toomanydirs'];
-				$field.= '<input type="text" name="path" value="' . htmlspecialchars($value) . '" />';
+				$field.= '<br /><input type="text" name="path" value="' . htmlspecialchars($value) . '" />';
 			}
 		}
 		else
