@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.inserttask.php 1388 2010-10-23 10:24:03Z d00p $
+ * @version    $Id: function.inserttask.php 1450 2010-11-09 09:16:08Z d00p $
  */
 
 /**
@@ -43,8 +43,8 @@ function inserttask($type, $param1 = '', $param2 = '', $param3 = '', $param4 = '
 	       && $param1 != ''
 	       && $param2 != ''
 	       && $param3 != ''
-	       && $param4 != '')
-	{
+	       && ($param4 == 0 || $param4 == 1)
+	) {
 		$data = Array();
 		$data['loginname'] = $param1;
 		$data['uid'] = $param2;
