@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.updateFunctions.php 460 2010-02-25 07:05:23Z d00p $
+ * @version    $Id: function.updateFunctions.php 944 2010-05-17 08:52:37Z d00p $
  */
 
 /*
@@ -115,7 +115,7 @@ function hasUpdates($to_check = null)
  */
 function showUpdateStep($task = null, $needs_status = true)
 {
-	global $updatelog;
+	global $updatelog, $filelog;
 	
 	// output
 	echo $task;
@@ -126,6 +126,7 @@ function showUpdateStep($task = null, $needs_status = true)
 	}
 	
 	$updatelog->logAction(ADM_ACTION, LOG_WARNING, $task);
+	$filelog->logAction(ADM_ACTION, LOG_WARNING, $task);
 }
 
 /*
@@ -140,7 +141,7 @@ function showUpdateStep($task = null, $needs_status = true)
  */
 function lastStepStatus($status = -1, $message = '')
 {
-	global $updatelog;
+	global $updatelog, $filelog;
 	
 	switch($status)
 	{
@@ -164,8 +165,35 @@ function lastStepStatus($status = -1, $message = '')
 	// output
 	echo "<span style=\"margin-left: 5em; font-weight: bold; color: #".$status_color."\">".$status_sign."</span><br />";
 	
-	if($status == -1)
+	if($status == -1 || $status == 2)
 	{
 		$updatelog->logAction(ADM_ACTION, LOG_WARNING, 'Attention - last update task failed!!!');
+		$filelog->logAction(ADM_ACTION, LOG_WARNING, 'Attention - last update task failed!!!');
+	}
+	elseif($status == 0 || $status == 1)
+	{
+		$filelog->logAction(ADM_ACTION, LOG_WARNING, 'Success');
 	}
 }
+
+/**
+ * validate if full path to update.log is sane
+ * if not, the update.log is created in /tmp/
+ *  
+ * @param string $filename the file name to validate
+ * 
+ * @return string the full path with filename (can differ if not writeable => /tmp)
+ */
+function validateUpdateLogFile($filename)
+{
+	if(!is_dir($filename))
+	{
+		$fh = @fopen($filename, 'a');
+		if($fh)
+		{
+			fclose($fh);
+			return $filename;
+		}
+	}
+	return '/tmp/froxlor_update.log';
+}
