@@ -16,7 +16,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: french.lng.php 759 2010-04-09 19:24:17Z EleRas $
+ * @version    $Id: french.lng.php 1338 2010-10-15 06:50:25Z d00p $
  */
 
 /**
@@ -894,13 +894,6 @@ $lng['pwdreminder']['success'] = 'Mot de passe correctement rinitialiser.<br />V
 $lng['serversettings']['allow_password_reset']['title'] = 'Permettre aux clients de rinitialiser leurs mots de passe';
 $lng['pwdreminder']['notallowed'] = 'La rinitialisation des mots de passe est dsactive.';
 
-// ADDED IN 1.2.19-svn20
-
-$lng['serversettings']['awstats_path']['title'] = 'Dossier CGI-BIN de AWStats';
-$lng['serversettings']['awstats_path']['description'] = 'exemple : /var/www/cgi-bin/';
-$lng['serversettings']['awstats_updateall_command']['title'] = 'Emplacement de "awstats_updateall.pl"';
-$lng['serversettings']['awstats_updateall_command']['description'] = 'exemple : /usr/share/awstats/tools/awstats_updateall.pl';
-
 // ADDED IN 1.2.19-svn21
 
 $lng['customer']['title'] = 'Titre';
