@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 1367 2010-10-19 19:32:53Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1508 2010-11-29 07:44:24Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -504,6 +504,15 @@ class apache
 					$stats_text.= '  Alias /webalizer "' . makeCorrectFile($domain['customerroot'] . '/webalizer') . '"' . "\n";
 				}
 			}
+			// if the docroots are equal, we still have to set an alias for awstats
+			// because the stats are in /awstats/[domain], not just /awstats/
+			// also, the awstats-icons are someplace else too!
+			// -> webalizer does not need this!
+			elseif($this->settings['system']['awstats_enabled'] == '1')
+			{
+				$stats_text.= '  Alias /awstats "' . makeCorrectFile($domain['documentroot'] . '/awstats/' . $domain['domain']) . '"' . "\n";
+				$stats_text.= '  Alias /awstats-icon "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '"' . "\n";
+			}
 		}
 
 		return $stats_text;
@@ -612,7 +621,7 @@ class apache
 				// After inserting the AWStats information, 
 				// be sure to build the awstats conf file as well
 				// and chown it using $awstats_params, #258
-				$awstats_param = array(
+				$awstats_params = array(
 					'loginname' => $domain['loginname'],
 					'guid' => $domain['guid'],
 					'documentroot' => $domain['documentroot']
@@ -631,12 +640,14 @@ class apache
 	protected function getVhostFilename($domain, $ssl_vhost = false)
 	{
 		if((int)$domain['parentdomainid'] == 0 
+			&& isCustomerStdSubdomain((int)$domain['id']) == false
 			&& ((int)$domain['ismainbutsubto'] == 0
 			|| domainMainToSubExists($domain['ismainbutsubto']) == false)
 		) {
 			$vhost_no = '22';
 		}
 		elseif((int)$domain['parentdomainid'] == 0 
+			&& isCustomerStdSubdomain((int)$domain['id']) == false
 			&& (int)$domain['ismainbutsubto'] > 0
 		) {
 			$vhost_no = '21';
