@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1367 2010-10-19 19:32:53Z d00p $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1508 2010-11-29 07:44:24Z d00p $
  */
 
 /*
@@ -77,11 +77,13 @@ class lighttpd
 			{
 				$ip = '[' . $row_ipsandports['ip'] . ']';
 				$port = $row_ipsandports['port'];
+				$ipv6 = 'server.use-ipv6 = "enable"'."\n";
 			}
 			else
 			{
 				$ip = $row_ipsandports['ip'];
 				$port = $row_ipsandports['port'];
+				$ipv6 = '';
 			}
 
 			fwrite($this->debugHandler, '  lighttpd::createIpPort: creating ip/port settings for  ' . $ip . ":" . $port . "\n");
@@ -99,6 +101,7 @@ class lighttpd
 			{
 				$this->lighttpd_data[$vhost_filename].= 'server.port = ' . $port . "\n";
 				$this->lighttpd_data[$vhost_filename].= 'server.bind = "' . $ip . '"' . "\n";
+				$this->lighttpd_data[$vhost_filename].= $ipv6;
 			}
 			
 			if($row_ipsandports['vhostcontainer'] == '1')
@@ -306,6 +309,7 @@ class lighttpd
 				$_inc_path = substr($_tmp_path, $_pos+1);
 
 				if((int)$domain['parentdomainid'] == 0 
+					&& isCustomerStdSubdomain((int)$domain['id']) == false
 					&& ((int)$domain['ismainbutsubto'] == 0
 					|| domainMainToSubExists($domain['ismainbutsubto']) == false) 
 				) {
@@ -316,6 +320,7 @@ class lighttpd
 					}
 				}
 				elseif((int)$domain['parentdomainid'] == 0 
+					&& isCustomerStdSubdomain((int)$domain['id']) == false
 					&& (int)$domain['ismainbutsubto'] > 0
 				) {
 					$vhost_no = '51';
@@ -558,12 +563,12 @@ class lighttpd
 				// After inserting the AWStats information, 
 				// be sure to build the awstats conf file as well
 				// and chown it using $awstats_params, #258
-				$awstats_param = array(
+				$awstats_params = array(
 					'loginname' => $domain['loginname'],
 					'guid' => $domain['guid'],
 					'documentroot' => $domain['documentroot']
 				);
-				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot'], $awstats_param);
+				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot'], $awstats_params);
 			}
 		}
 
@@ -855,6 +860,15 @@ class lighttpd
 					$stats_text.= '  alias.url = ( "/webalizer/" => "'.makeCorrectFile($domain['customerroot'] . '/webalizer').'" )' . "\n";
 				}
 			}
+			// if the docroots are equal, we still have to set an alias for awstats
+			// because the stats are in /awstats/[domain], not just /awstats/
+			// also, the awstats-icons are someplace else too!
+			// -> webalizer does not need this!
+			elseif($this->settings['system']['awstats_enabled'] == '1')
+			{
+				$stats_text.= '  alias.url = ( "/awstats/" => "'.makeCorrectFile($domain['documentroot'] . '/awstats/' . $domain['domain']).'" )' . "\n";
+				$stats_text.= '  alias.url = ( "/awstats-icon" => "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '" )' . "\n";
+			}
 		}
 
 		return $stats_text;
