@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.25.lighttpd_fcgid.php 1190 2010-07-19 09:48:54Z d00p $
+ * @version    $Id: cron_tasks.inc.http.25.lighttpd_fcgid.php 1243 2010-08-10 07:57:48Z d00p $
  */
 
 /*
@@ -173,7 +173,7 @@ class lighttpd_fcgid extends lighttpd
 
 			if(file_exists($starter_filename))
 			{
-				safe_exec('chattr -i ' . escapeshellarg($starter_filename));
+				removeImmutable($starter_filename);
 			}
 
 			$starter_file_handler = fopen($starter_filename, 'w');
@@ -181,7 +181,7 @@ class lighttpd_fcgid extends lighttpd
 			fclose($starter_file_handler);
 			safe_exec('chmod 750 ' . escapeshellarg($starter_filename));
 			safe_exec('chown ' . $domain['guid'] . ':' . $domain['guid'] . ' ' . escapeshellarg($starter_filename));
-			safe_exec('chattr +i ' . escapeshellarg($starter_filename));
+			setImmutable($starter_filename);
 
 			// define the php.ini
 
