@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_traffic_report.php 518 2010-03-03 08:51:13Z d00p $
+ * @version    $Id: cron_traffic_report.php 1205 2010-07-27 09:59:53Z d00p $
  */
 
 fwrite($debugHandler, 'Trafficreport run started...' . "\n");
@@ -25,7 +25,7 @@ $yesterday = time() - (60 * 60 * 24);
  */
 
 require (dirname(__FILE__) . '/../lib/class.phpmailer.php');
-$mail = new PHPMailer();
+$mail = new PHPMailer(true);
 $mail->SetFrom($settings['panel']['adminmail'], 'Froxlor Administrator');
 
 // Warn the customers at 90% traffic-usage
