@@ -14,24 +14,13 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_used_tickets_reset.php 115 2010-01-25 13:19:45Z EleRas $
+ * @version    $Id: cron_used_tickets_reset.php 1333 2010-10-12 06:21:08Z d00p $
  */
 
 /**
  * RESET USED TICKETS COUNTER
  */
 
-fwrite($debugHandler, 'Used tickets reset run started...' . "\n");
-$now = time();
-$cycle = $settings['ticket']['reset_cycle'];
-
-if($cycle == '0'
-   || ($cycle == '1' && (date("j", $now) == '1' || date("j", $now) == '7' || date("j", $now) == '14' || date("j", $now) == '21'))
-   || ($cycle == '2' && date("j", $now) == '1')
-   || ($cycle == '3' && date("dm", $now) == '0101'))
-{
-	fwrite($debugHandler, 'Resetting customers used ticket counter' . "\n");
-	$db->query("UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `tickets_used` = '0'");
-}
-
-?>
\ No newline at end of file
+fwrite($debugHandler, 'Resetting customers used ticket counter' . "\n");
+$cronlog->logAction(CRON_ACTION, LOG_INFO, "Resetting customers used ticket counter");
+$db->query("UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `tickets_used` = '0'");
